# TODO

1. add a command to save the "include/exclude" rule, and the results. The results can be updates with its rules.
2. add a command to set the save-path. the default save-path is the path you run the script.
3. add smp support?
4. add multi-files download support.